@@ -171,7 +171,7 @@ def lonlat2thetaphi(lon, lat):
     theta, phi : float, scalar or array-like
       The co-latitude and longitude in radians
     """
-    return np.pi / 2. - np.radians(lat), np.radians(lon)
+    return np.pi / 2.0 - np.radians(lat), np.radians(lon)
 
 
 def thetaphi2lonlat(theta, phi):
@@ -189,7 +189,7 @@ def thetaphi2lonlat(theta, phi):
     lon, lat : float, scalar or array-like
       The longitude and latitude in degrees
     """
-    return np.degrees(phi), 90. - np.degrees(theta)
+    return np.degrees(phi), 90.0 - np.degrees(theta)
 
 
 def maptype(m):
@@ -221,8 +221,13 @@ def maptype(m):
         raise TypeError("input map is a scalar")
     if len(m) == 0:
         raise TypeError("input map has length zero")
-    if hasattr(m[0], "__len__"):
+
+    try:
         npix = len(m[0])
+    except TypeError:
+        npix = None
+
+    if npix is not None:
         for mm in m[1:]:
             if len(mm) != npix:
                 raise TypeError("input maps have different npix")
@@ -301,7 +306,7 @@ def accept_ma(f):
     return wrapper
 
 
-def mask_bad(m, badval=UNSEEN, rtol=1.e-5, atol=1.e-8):
+def mask_bad(m, badval=UNSEEN, rtol=1.0e-5, atol=1.0e-8):
     """Returns a bool array with ``True`` where m is close to badval.
 
     Parameters
@@ -340,7 +345,7 @@ def mask_bad(m, badval=UNSEEN, rtol=1.e-5, atol=1.e-8):
     return np.absolute(m - badval) <= atol + rtol * np.absolute(badval)
 
 
-def mask_good(m, badval=UNSEEN, rtol=1.e-5, atol=1.e-8):
+def mask_good(m, badval=UNSEEN, rtol=1.0e-5, atol=1.0e-8):
     """Returns a bool array with ``False`` where m is close to badval.
 
     Parameters
@@ -442,21 +447,26 @@ def ang2pix(nside, theta, phi, nest=False, lonlat=False):
 
     Examples
     --------
+    Note that some of the test inputs below that are on pixel boundaries
+    such as theta=pi/2, phi=pi/2, have a tiny value of 1e-15 added to them
+    to make them reproducible on i386 machines using x87 floating point
+    instruction set (see https://github.com/healpy/healpy/issues/528).
+
     >>> import healpy as hp
     >>> hp.ang2pix(16, np.pi/2, 0)
     1440
 
-    >>> hp.ang2pix(16, [np.pi/2, np.pi/4, np.pi/2, 0, np.pi], [0., np.pi/4, np.pi/2, 0, 0])
-    array([1440,  427, 1520,    0, 3068])
+    >>> print(hp.ang2pix(16, [np.pi/2, np.pi/4, np.pi/2, 0, np.pi], [0., np.pi/4, np.pi/2 + 1e-15, 0, 0]))
+    [1440  427 1520    0 3068]
 
-    >>> hp.ang2pix(16, np.pi/2, [0, np.pi/2])
-    array([1440, 1520])
+    >>> print(hp.ang2pix(16, np.pi/2, [0, np.pi/2 + 1e-15]))
+    [1440 1520]
 
-    >>> hp.ang2pix([1, 2, 4, 8, 16], np.pi/2, 0)
-    array([   4,   12,   72,  336, 1440])
+    >>> print(hp.ang2pix([1, 2, 4, 8, 16], np.pi/2, 0))
+    [   4   12   72  336 1440]
 
-    >>> hp.ang2pix([1, 2, 4, 8, 16], 0, 0, lonlat=True)
-    array([   4,   12,   72,  336, 1440])
+    >>> print(hp.ang2pix([1, 2, 4, 8, 16], 0, 0, lonlat=True))
+    [   4   12   72  336 1440]
     """
 
     check_nside(nside, nest=nest)
@@ -484,7 +494,7 @@ def pix2ang(nside, ipix, nest=False, lonlat=False):
       if True, assume NESTED pixel ordering, otherwise, RING pixel ordering
     lonlat : bool, optional
       If True, return angles will be longitude and latitude in degree,
-      otherwise, angles will be longitude and co-latitude in radians (default)
+      otherwise, angles will be co-latitude and longitude in radians (default)
 
     Returns
     -------
@@ -553,8 +563,8 @@ def xyf2pix(nside, x, y, face, nest=False):
     >>> hp.xyf2pix(16, 8, 8, 4)
     1440
 
-    >>> hp.xyf2pix(16, [8, 8, 8, 15, 0], [8, 8, 7, 15, 0], [4, 0, 5, 0, 8])
-    array([1440,  427, 1520,    0, 3068])
+    >>> print(hp.xyf2pix(16, [8, 8, 8, 15, 0], [8, 8, 7, 15, 0], [4, 0, 5, 0, 8]))
+    [1440  427 1520    0 3068]
     """
     check_nside(nside, nest=nest)
     if nest:
@@ -633,11 +643,11 @@ def vec2pix(nside, x, y, z, nest=False):
     >>> hp.vec2pix(16, 1, 0, 0)
     1504
 
-    >>> hp.vec2pix(16, [1, 0], [0, 1], [0, 0])
-    array([1504, 1520])
+    >>> print(hp.vec2pix(16, [1, 0], [0, 1], [0, 0]))
+    [1504 1520]
 
-    >>> hp.vec2pix([1, 2, 4, 8], 1, 0, 0)
-    array([  4,  20,  88, 368])
+    >>> print(hp.vec2pix([1, 2, 4, 8], 1, 0, 0))
+    [  4  20  88 368]
     """
     if nest:
         return pixlib._vec2pix_nest(nside, x, y, z)
@@ -725,7 +735,7 @@ def vec2ang(vectors, lonlat=False):
       the vector(s) to convert, shape is (3,) or (N, 3)
     lonlat : bool, optional
       If True, return angles will be longitude and latitude in degree,
-      otherwise, angles will be longitude and co-latitude in radians (default)
+      otherwise, angles will be co-latitude and longitude in radians (default)
 
     Returns
     -------
@@ -772,11 +782,11 @@ def ring2nest(nside, ipix):
     >>> hp.ring2nest(16, 1504)
     1130
 
-    >>> hp.ring2nest(2, np.arange(10))
-    array([ 3,  7, 11, 15,  2,  1,  6,  5, 10,  9])
+    >>> print(hp.ring2nest(2, np.arange(10)))
+    [ 3  7 11 15  2  1  6  5 10  9]
 
-    >>> hp.ring2nest([1, 2, 4, 8], 11)
-    array([ 11,  13,  61, 253])
+    >>> print(hp.ring2nest([1, 2, 4, 8], 11))
+    [ 11  13  61 253]
     """
     check_nside(nside, nest=True)
     return pixlib._ring2nest(nside, ipix)
@@ -807,11 +817,11 @@ def nest2ring(nside, ipix):
     >>> hp.nest2ring(16, 1130)
     1504
 
-    >>> hp.nest2ring(2, np.arange(10))
-    array([13,  5,  4,  0, 15,  7,  6,  1, 17,  9])
+    >>> print(hp.nest2ring(2, np.arange(10)))
+    [13  5  4  0 15  7  6  1 17  9]
 
-    >>> hp.nest2ring([1, 2, 4, 8], 11)
-    array([ 11,   2,  12, 211])
+    >>> print(hp.nest2ring([1, 2, 4, 8], 11))
+    [ 11   2  12 211]
     """
     check_nside(nside, nest=True)
     return pixlib._nest2ring(nside, ipix)
@@ -931,18 +941,13 @@ def nside2npix(nside):
     Parameters
     ----------
     nside : int
-      healpix nside parameter; an exception is raised if nside is not valid
-      (nside must be a power of 2, less than 2**30)
+      healpix nside parameter
 
     Returns
     -------
     npix : int
       corresponding number of pixels
 
-    Notes
-    -----
-    Raise a ValueError exception if nside is not valid.
-
     Examples
     --------
     >>> import healpy as hp
@@ -1113,7 +1118,7 @@ def npix2nside(npix):
     """
     if not isnpixok(npix):
         raise ValueError("Wrong pixel number (it is not 12*nside**2)")
-    return int(np.sqrt(npix / 12.))
+    return int(np.sqrt(npix / 12.0))
 
 
 def order2nside(order):
@@ -1139,8 +1144,8 @@ def order2nside(order):
     >>> hp.order2nside(7)
     128
 
-    >>> hp.order2nside(np.arange(8))
-    array([  1,   2,   4,   8,  16,  32,  64, 128])
+    >>> print(hp.order2nside(np.arange(8)))
+    [  1   2   4   8  16  32  64 128]
 
     >>> hp.order2nside(31)
     Traceback (most recent call last):
@@ -1232,7 +1237,7 @@ def isnpixok(npix):
     >>> hp.isnpixok([12, 768, 1002])
     array([ True,  True, False], dtype=bool)
     """
-    nside = np.sqrt(np.asarray(npix) / 12.)
+    nside = np.sqrt(np.asarray(npix) / 12.0)
     return nside == np.floor(nside)
 
 
@@ -1320,24 +1325,42 @@ def get_interp_weights(nside, theta, phi=None, nest=False, lonlat=False):
 
     Examples
     --------
+    Note that some of the test inputs below that are on pixel boundaries
+    such as theta=pi/2, phi=pi/2, have a tiny value of 1e-15 added to them
+    to make them reproducible on i386 machines using x87 floating point
+    instruction set (see https://github.com/healpy/healpy/issues/528).
+
     >>> import healpy as hp
-    >>> hp.get_interp_weights(1, 0)
-    (array([0, 1, 4, 5]), array([ 1.,  0.,  0.,  0.]))
+    >>> pix, weights = hp.get_interp_weights(1, 0)
+    >>> print(pix)
+    [0 1 4 5]
+    >>> weights
+    array([ 1.,  0.,  0.,  0.])
 
-    >>> hp.get_interp_weights(1, 0, 0)
-    (array([1, 2, 3, 0]), array([ 0.25,  0.25,  0.25,  0.25]))
+    >>> pix, weights = hp.get_interp_weights(1, 0, 0)
+    >>> print(pix)
+    [1 2 3 0]
+    >>> weights
+    array([ 0.25,  0.25,  0.25,  0.25])
 
-    >>> hp.get_interp_weights(1, 0, 90, lonlat=True)
-    (array([1, 2, 3, 0]), array([ 0.25,  0.25,  0.25,  0.25]))
+    >>> pix, weights = hp.get_interp_weights(1, 0, 90, lonlat=True)
+    >>> print(pix)
+    [1 2 3 0]
+    >>> weights
+    array([ 0.25,  0.25,  0.25,  0.25])
 
-    >>> hp.get_interp_weights(1, [0, np.pi/2], 0)
-    (array([[ 1,  4],
-           [ 2,  5],
-           [ 3, 11],
-           [ 0,  8]]), array([[ 0.25,  1.  ],
-           [ 0.25,  0.  ],
-           [ 0.25,  0.  ],
-           [ 0.25,  0.  ]]))
+    >>> pix, weights = hp.get_interp_weights(1, [0, np.pi/2 + 1e-15], 0)
+    >>> print(pix)
+    [[ 1  4]
+     [ 2  5]
+     [ 3 11]
+     [ 0  8]]
+    >>> np.testing.assert_allclose(
+    ...     weights,
+    ...     np.array([[ 0.25,  1.  ],
+    ...               [ 0.25,  0.  ],
+    ...               [ 0.25,  0.  ],
+    ...               [ 0.25,  0.  ]]), rtol=0, atol=1e-14)
     """
     check_nside(nside, nest=nest)
     if phi is None:
@@ -1384,14 +1407,14 @@ def get_all_neighbours(nside, theta, phi=None, nest=False, lonlat=False):
     Examples
     --------
     >>> import healpy as hp
-    >>> hp.get_all_neighbours(1, 4)
-    array([11,  7,  3, -1,  0,  5,  8, -1])
+    >>> print(hp.get_all_neighbours(1, 4))
+    [11  7  3 -1  0  5  8 -1]
 
-    >>> hp.get_all_neighbours(1, np.pi/2, np.pi/2)
-    array([ 8,  4,  0, -1,  1,  6,  9, -1])
+    >>> print(hp.get_all_neighbours(1, np.pi/2, np.pi/2))
+    [ 8  4  0 -1  1  6  9 -1]
 
-    >>> hp.get_all_neighbours(1, 90, 0, lonlat=True)
-    array([ 8,  4,  0, -1,  1,  6,  9, -1])
+    >>> print(hp.get_all_neighbours(1, 90, 0, lonlat=True))
+    [ 8  4  0 -1  1  6  9 -1]
     """
     check_nside(nside, nest=nest)
     if phi is not None:
@@ -1751,7 +1774,7 @@ def get_min_valid_nside(npix):
     >>> hp.pixelfunc.get_min_valid_nside(768)
     8
     """
-    order = 0.5 * np.log2(npix / 12.)
+    order = 0.5 * np.log2(npix / 12.0)
     return 1 << int(np.ceil(order))
 
 
