@@ -331,7 +331,7 @@ class Rotator(object):
     def do_rot(self, i):
         """Returns True if rotation is not (close to) identity.
         """
-        return not np.allclose(self.rots[i], np.zeros(3), rtol=0., atol=1.e-15)
+        return not np.allclose(self.rots[i], np.zeros(3), rtol=0.0, atol=1.0e-15)
 
     def angle_ref(self, *args, **kwds):
         """Compute the angle between transverse reference direction of initial and final frames
@@ -372,21 +372,25 @@ class Rotator(object):
         else:
             raise TypeError("Either 1, 2 or 3 arguments accepted")
         vp = R(v, inv=inv)
-        north_pole = R([0., 0., 1.], inv=inv)
+        north_pole = R([0.0, 0.0, 1.0], inv=inv)
         sinalpha = north_pole[0] * vp[1] - north_pole[1] * vp[0]
         cosalpha = north_pole[2] - vp[2] * np.dot(north_pole, vp)
         return np.arctan2(sinalpha, cosalpha)
 
-    def rotate_alm(self, alm, lmax=None, mmax=None):
+    def rotate_alm(self, alm, lmax=None, mmax=None, inplace=False):
         """Rotate Alms with the transform defined in the Rotator object
 
         see the docstring of the rotate_alm function defined
         in the healpy package, this function **returns** the rotated alms,
         does not rotate in place"""
 
-        rotated_alm = alm.copy()  # rotate_alm works inplace
+        if not inplace:
+            rotated_alm = alm.copy()  # rotate_alm works inplace
+        else:
+            rotated_alm = alm
         rotate_alm(rotated_alm, matrix=self.mat, lmax=lmax, mmax=mmax)
-        return rotated_alm
+        if not inplace:
+            return rotated_alm
 
     def rotate_map_alms(self, m, use_pixel_weights=True, lmax=None, mmax=None):
         """Rotate a HEALPix map to a new reference frame in spherical harmonics space
@@ -608,7 +612,7 @@ def vec2dir(vec, vy=None, vz=None, lonlat=False):
     if lonlat:
         ang = np.degrees(ang)
         np.negative(ang[0, :], ang[0, :])
-        ang[0, :] += 90.
+        ang[0, :] += 90.0
         return ang[::-1, :].squeeze()
     else:
         return ang.squeeze()
@@ -641,7 +645,7 @@ def dir2vec(theta, phi=None, lonlat=False):
         theta, phi = theta
     if lonlat:
         lon, lat = theta, phi
-        theta, phi = np.pi / 2. - np.radians(lat), np.radians(lon)
+        theta, phi = np.pi / 2.0 - np.radians(lat), np.radians(lon)
     ct, st, cp, sp = np.cos(theta), np.sin(theta), np.cos(phi), np.sin(phi)
     vec = np.empty((3, ct.size), np.float64)
     vec[0, :] = st * cp
@@ -802,14 +806,14 @@ def normalise_rot(rot, deg=False):
    is in radian.
    """
     if deg:
-        convert = np.pi / 180.
+        convert = np.pi / 180.0
     else:
-        convert = 1.
+        convert = 1.0
     if rot is None:
         rot = np.zeros(3)
     else:
         rot = np.array(rot, np.float64).flatten() * convert
-        rot.resize(3)
+        rot.resize(3, refcheck=False)
     return rot
 
 
@@ -827,7 +831,7 @@ def get_rotation_matrix(rot, deg=False, eulertype="ZYX"):
       - normrot: the normalized version of the input rot.
    """
     rot = normalise_rot(rot, deg=deg)
-    if not np.allclose(rot, np.zeros(3), rtol=0., atol=1.e-15):
+    if not np.allclose(rot, np.zeros(3), rtol=0.0, atol=1.0e-15):
         do_rot = True
     else:
         do_rot = False
@@ -864,8 +868,8 @@ def get_coordconv_matrix(coord):
         matconv = np.identity(3)
         do_conv = False
     else:
-        eps = 23.452294 - 0.0130125 - 1.63889E-6 + 5.02778E-7
-        eps = eps * np.pi / 180.
+        eps = 23.452294 - 0.0130125 - 1.63889e-6 + 5.02778e-7
+        eps = eps * np.pi / 180.0
 
         # ecliptic to galactic
         e2g = np.array(
@@ -879,9 +883,9 @@ def get_coordconv_matrix(coord):
         # ecliptic to equatorial
         e2q = np.array(
             [
-                [1., 0., 0.],
-                [0., np.cos(eps), -1. * np.sin(eps)],
-                [0., np.sin(eps), np.cos(eps)],
+                [1.0, 0.0, 0.0],
+                [0.0, np.cos(eps), -1.0 * np.sin(eps)],
+                [0.0, np.sin(eps), np.cos(eps)],
             ]
         )
 
@@ -1155,7 +1159,7 @@ def euler_matrix_new(a1, a2, a3, X=True, Y=False, ZYX=False, deg=False):
 
     convert = 1.0
     if deg:
-        convert = np.pi / 180.
+        convert = np.pi / 180.0
 
     c1 = np.cos(a1 * convert)
     s1 = np.sin(a1 * convert)
