@@ -24,10 +24,10 @@ import six
 pi = np.pi
 import warnings
 import astropy.io.fits as pf
-from scipy.integrate import simps
+from scipy.integrate import trapz
 from astropy.utils import data
 
-data.conf.dataurl = "https://healpy.github.io/healpy-data/"
+DATAURL = "https://healpy.github.io/healpy-data/"
 
 from . import _healpy_sph_transform_lib as sphtlib
 from . import _sphtools as _sphtools
@@ -44,7 +44,9 @@ class FutureChangeWarning(UserWarning):
 
 
 DATAPATH = os.path.join(os.path.dirname(os.path.abspath(__file__)), "data")
-MAX_NSIDE = 8192  # The maximum nside up to which most operations (e.g. map2alm) will work
+MAX_NSIDE = (
+    8192
+)  # The maximum nside up to which most operations (e.g. map2alm) will work
 
 # Spherical harmonics transformation
 def anafast(
@@ -206,10 +208,13 @@ def map2alm(
     if use_pixel_weights:
         if use_weights:
             raise RuntimeError("Either use pixel or ring weights")
-        pixel_weights_filename = data.get_pkg_data_filename(
-            "full_weights/healpix_full_weights_nside_%04d.fits" % nside,
-            package="healpy",
-        )
+        with data.conf.set_temp("dataurl", DATAURL), data.conf.set_temp(
+            "remote_timeout", 30
+        ):
+            pixel_weights_filename = data.get_pkg_data_filename(
+                "full_weights/healpix_full_weights_nside_%04d.fits" % nside,
+                package="healpy",
+            )
     else:
         pixel_weights_filename = None
 
@@ -581,6 +586,12 @@ class Alm(object):
     def getidx(lmax, l, m):
         """Returns index corresponding to (l,m) in an array describing alm up to lmax.
 
+        In HEALPix C++ and healpy, :math:`a_{lm}` coefficients are stored ordered by
+        :math:`m`. I.e. if :math:`\ell_{max}` is 16, the first 16 elements are
+        :math:`m=0, \ell=0-16`, then the following 15 elements are :math:`m=1, \ell=1-16`,
+        then :math:`m=2, \ell=2-16` and so on until the last element, the 153th, is
+        :math:`m=16, \ell=16`.
+
         Parameters
         ----------
         lmax : int
@@ -757,7 +768,7 @@ def smoothalm(
       Otherwise, a copy is made.
     """
     if (sigma is None) & (beam_window is None):
-        sigma = fwhm / (2. * np.sqrt(2. * np.log(2.)))
+        sigma = fwhm / (2.0 * np.sqrt(2.0 * np.log(2.0)))
 
     if verbose:
         if beam_window is None:
@@ -768,7 +779,7 @@ def smoothalm(
             )
             print(
                 "-> fwhm is {0:f} arcmin".format(
-                    sigma * 60 * 180 / pi * (2. * np.sqrt(2. * np.log(2.)))
+                    sigma * 60 * 180 / pi * (2.0 * np.sqrt(2.0 * np.log(2.0)))
                 )
             )
         else:
@@ -800,7 +811,7 @@ def smoothalm(
                 "Wrong alm size for the given "
                 "mmax (len(alms[%d]) = %d)." % (ialm, len(alm))
             )
-        ell = np.arange(lmax + 1.)
+        ell = np.arange(lmax + 1.0)
         s = 2 if ialm >= 1 and pol else 0
         if beam_window is None:
             fact = np.exp(-0.5 * (ell * (ell + 1) - s ** 2) * sigma ** 2)
@@ -837,6 +848,7 @@ def smoothing(
     lmax=None,
     mmax=None,
     use_weights=False,
+    use_pixel_weights=False,
     datapath=None,
     verbose=True,
 ):
@@ -870,6 +882,8 @@ def smoothing(
       Maximum m of the alm. Default: lmax
     use_weights: bool, scalar, optional
       If True, use the ring weighting. Default: False.
+    use_pixel_weights: bool, optional
+      If True, use pixel by pixel weighting, healpy will automatically download the weights, if needed
     datapath : None or str, optional
       If given, the directory where to find the weights data.
     verbose : bool, optional
@@ -905,6 +919,7 @@ def smoothing(
             iter=iter,
             pol=pol,
             use_weights=use_weights,
+            use_pixel_weights=use_pixel_weights,
             datapath=datapath,
         )
         smoothalm(
@@ -927,6 +942,7 @@ def smoothing(
                 iter=iter,
                 pol=pol,
                 use_weights=use_weights,
+                use_pixel_weights=use_pixel_weights,
                 datapath=datapath,
             )
             smoothalm(
@@ -944,7 +960,7 @@ def smoothing(
     return output_map
 
 
-def pixwin(nside, pol=False):
+def pixwin(nside, pol=False, lmax=None):
     """Return the pixel window function for the given nside.
 
     Parameters
@@ -953,6 +969,8 @@ def pixwin(nside, pol=False):
       The nside for which to return the pixel window function
     pol : bool, optional
       If True, return also the polar pixel window. Default: False
+    lmax : int, optional
+        Maximum l of the power spectrum (default: 3*nside-1) 
 
     Returns
     -------
@@ -960,6 +978,10 @@ def pixwin(nside, pol=False):
       The temperature pixel window function, or a tuple with both
       temperature and polarisation pixel window functions.
     """
+
+    if lmax is None:
+        lmax = 3 * nside - 1
+
     datapath = DATAPATH
     if not pixelfunc.isnsideok(nside):
         raise ValueError("Wrong nside value (must be a power of two).")
@@ -970,9 +992,9 @@ def pixwin(nside, pol=False):
     pw = pf.getdata(fname)
     pw_temp, pw_pol = pw.field(0), pw.field(1)
     if pol:
-        return pw_temp, pw_pol
+        return pw_temp[: lmax + 1], pw_pol[: lmax + 1]
     else:
-        return pw_temp
+        return pw_temp[: lmax + 1]
 
 
 def alm2map_der1(alm, nside, lmax=None, mmax=None):
@@ -1076,16 +1098,16 @@ def gauss_beam(fwhm, lmax=512, pol=False):
         otherwise (lmax+1, 4) contains polarized beam
     """
 
-    sigma = fwhm / np.sqrt(8. * np.log(2.))
+    sigma = fwhm / np.sqrt(8.0 * np.log(2.0))
     ell = np.arange(lmax + 1)
     sigma2 = sigma ** 2
-    g = np.exp(-.5 * ell * (ell + 1) * sigma2)
+    g = np.exp(-0.5 * ell * (ell + 1) * sigma2)
 
     if not pol:  # temperature-only beam
         return g
     else:  # polarization beam
         # polarization factors [1, 2 sigma^2, 2 sigma^2, sigma^2]
-        pol_factor = np.exp([0., 2 * sigma2, 2 * sigma2, sigma2])
+        pol_factor = np.exp([0.0, 2 * sigma2, 2 * sigma2, sigma2])
         return g[:, np.newaxis] * pol_factor
 
 
@@ -1106,7 +1128,7 @@ def bl2beam(bl, theta):
     beam : array
         (Circular) beam profile b(theta).
     """
-    
+
     lmax = len(bl) - 1
     nx = len(theta)
     x = np.cos(theta)
@@ -1159,12 +1181,12 @@ def beam2bl(beam, theta, lmax):
     p0 = np.ones(nx)
     p1 = np.copy(x)
 
-    window[0] = simps(beam * p0 * st, theta)
-    window[1] = simps(beam * p1 * st, theta)
+    window[0] = trapz(beam * p0 * st, theta)
+    window[1] = trapz(beam * p1 * st, theta)
 
     for l in np.arange(2, lmax + 1):
         p2 = x * p1 * (2 * l - 1) / l - p0 * (l - 1) / l
-        window[l] = simps(beam * p2 * st, theta)
+        window[l] = trapz(beam * p2 * st, theta)
         p0 = p1
         p1 = p2
 
@@ -1185,8 +1207,8 @@ def check_max_nside(nside):
 
     if nside > MAX_NSIDE:
         raise ValueError(
-            'nside {nside} of map cannot be larger than '
-            'MAX_NSIDE {max_nside}'.format(
-                nside=nside, max_nside=MAX_NSIDE))
+            "nside {nside} of map cannot be larger than "
+            "MAX_NSIDE {max_nside}".format(nside=nside, max_nside=MAX_NSIDE)
+        )
 
     return 0
